Index: trunk/LMDZ.PLUTO/util/startarchive2icosa/icosa_finalize.bash
===================================================================
--- trunk/LMDZ.PLUTO/util/startarchive2icosa/icosa_finalize.bash	(revision 3678)
+++ trunk/LMDZ.PLUTO/util/startarchive2icosa/icosa_finalize.bash	(revision 3679)
@@ -13,5 +13,4 @@
 module load nco
 
-# save start*nc from lmdz grid
 
 #conversion to netcdf 3 in order to rename and add variables, not properly done with netcdf4 files
@@ -22,19 +21,20 @@
 ncrename -v lon,longitude -v lat,latitude -d cell,physical_points\
          startphy_icosa_nc3.nc startphy_nc3.nc
-#Temporay soildepth array from Dynamico restartfi
-ncks -A -v soildepth restartfi.nc startphy_nc3.nc #You have to adapt to your own path
-# ncks -A -v subslope_dist restartfi.nc startphy_nc3.nc
-# ncks -A -v def_slope restartfi.nc startphy_nc3.nc
+#Temporay soildepth array from Dynamico startphy_icosa_ref
+ncks -A -v soildepth startphy_icosa_ref.nc startphy_nc3.nc #You have to adapt to your own path
+# ncks -A -v subslope_dist startphy_icosa_ref.nc startphy_nc3.nc
+# ncks -A -v def_slope startphy_icosa_ref.nc startphy_nc3.nc
 
 nccopy -k 4 startphy_nc3.nc startfi.nc
+cp startfi.nc startfi_before_finalize.nc
 
 #Temporary Time variable from start2archive; should be added with xios
 ncks -O -x -v time_counter startfi.nc startfi.nc_tmp
 ncks -A -v Time start.nc startfi.nc_tmp
 # ncks -A -v flux_geo restartfi.nc startfi.nc_tmp
 # ncks -A -v wstar restartfi.nc startfi.nc_tmp
 # ncks -A -v hmons restartfi.nc startfi.nc_tmp
 # ncks -A -v summit restartfi.nc startfi.nc_tmp
 # ncks -A -v base restartfi.nc startfi.nc_tmp
 cp startfi.nc_tmp startfi.nc
 
@@ -54,6 +54,8 @@
      start_icosa_ref.nc start_icosa.nc
 
-ncks -A -v W,geopot,q,nq start_icosa_ref.nc start_icosa.nc
+ncks -A -v q,nq start_icosa_ref.nc start_icosa.nc
 
+ncks -A -v latitude,longitude startphy_icosa_ref.nc startfi.nc
+ncks -A -v latitude,longitude startphy.nc startfi.nc
 # In the current version of Dynamico, the variable q for tracer is needed but unused.
 # To create this unused variable simply run this short python code
@@ -22,19 +21,20 @@
 ncks -O -x -v time_counter startfi.nc startfi.nc_tmp
 ncks -A -v Time start.nc startfi.nc_tmp
-# ncks -A -v flux_geo restartfi.nc startfi.nc_tmp
-# ncks -A -v wstar restartfi.nc startfi.nc_tmp
-# ncks -A -v hmons restartfi.nc startfi.nc_tmp
-# ncks -A -v summit restartfi.nc startfi.nc_tmp
-# ncks -A -v base restartfi.nc startfi.nc_tmp
+# ncks -A -v flux_geo startphy_icosa_ref.nc startfi.nc_tmp
+# ncks -A -v wstar startphy_icosa_ref.nc startfi.nc_tmp
+# ncks -A -v hmons startphy_icosa_ref.nc startfi.nc_tmp
+# ncks -A -v summit startphy_icosa_ref.nc startfi.nc_tmp
+# ncks -A -v base startphy_icosa_ref.nc startfi.nc_tmp
 cp startfi.nc_tmp startfi.nc
 
